package cn.shuzilm.odps;

import cn.shuzilm.odps.Utils;
import com.alibaba.fastjson.JSONObject;
import com.aliyun.odps.data.Record;
import com.aliyun.odps.data.TableInfo;
import com.aliyun.odps.mapred.JobClient;
import com.aliyun.odps.mapred.MapperBase;
import com.aliyun.odps.mapred.Mapper.TaskContext;
import com.aliyun.odps.mapred.conf.JobConf;
import com.aliyun.odps.mapred.utils.InputUtils;
import com.aliyun.odps.mapred.utils.OutputUtils;
import java.io.IOException;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Date;
import java.util.Iterator;
import org.apache.commons.lang.StringUtils;
import org.joda.time.DateTime;
import org.joda.time.format.DateTimeFormat;
import org.joda.time.format.DateTimeFormatter;

public class OdsIosDnaDetail2D {

   private static final String columns_index_json = "{\"aiuid\": 84, \"android_id\": 123, \"apkid\": 36, \"apkpath\": 87, \"apksize\": 86, \"app__label\": 19, \"battery__ac\": 45, \"battery__level\": 47, \"battery__usb\": 46, \"bd_deviceid\": 119, \"bluetooth\": 110, \"board\": 21, \"bootloader\": 22, \"bssid\": 105, \"bssid_list\": 107, \"cell_id\": 101, \"cid\": 98, \"cpu__abi\": 23, \"cpu__abi2\": 24, \"cpuinfo\": 42, \"curtime\": 88, \"device\": 25, \"did\": 0,\"tmp_did\": 0, \"did1\": 9, \"did2\": 10, \"did3\": 11, \"display\": 44, \"existing\": 122, \"first__install__time\": 15, \"fme\": 120, \"fonts\": 121, \"gateway_mac\": 8, \"gsm_current_phone_type\": 61, \"gsm_network_type\": 62, \"gsm_operator_isroaming\": 68, \"gsm_operator_numeric\": 95, \"gsm_sim_state\": 50, \"gsm_version_baseband\": 90, \"gsm_version_ril_impl\": 91, \"hardware\": 26, \"host\": 27, \"iccid\": 37, \"id\": 28, \"imei\": 34, \"imei__native\": 35, \"imei_validation\": 124, \"imsi\": 38, \"init_svc_adbd\": 99, \"ip\": 2, \"lac_id\": 103, \"last__update__time\": 16, \"launcher\": 41, \"ldid\": 93, \"mac__addr\": 6, \"mac__framework\": 7, \"manufacturer\": 29, \"md5\": 81, \"mobilestate\": 109, \"model\": 30, \"msg\": 94, \"net_hostname\": 51, \"networkstate\": 48, \"opt_id\": 102, \"persist_radio_plmnname_2\": 79, \"persist_sys_country\": 78, \"persist_sys_timezone\": 77, \"pid\": 113, \"pkg_name\": 100, \"pkglist\": 125, \"ppid\": 114, \"product\": 31, \"ram\": 111, \"ril_subscription_types\": 96, \"ro_adb_secure\": 69, \"ro_board_platform\": 85, \"ro_boot_serialno\": 54, \"ro_build_display_id\": 97, \"ro_build_fingerprint\": 52, \"ro_build_type\": 53, \"ro_build_version_release\": 64, \"ro_chipname\": 55, \"ro_com_google_clientidbase\": 66, \"ro_csc_country_code\": 74, \"ro_csc_sales_code\": 75, \"ro_debuggable\": 76, \"ro_gps_agps_provider\": 65, \"ro_kernel_qemu\": 72, \"ro_multisim_simslotcount\": 70, \"ro_nfc_port\": 71, \"ro_opengles_version\": 56, \"ro_product_board\": 57, \"ro_product_brand\": 58, \"ro_product_cpu_abi\": 59, \"ro_product_device\": 67, \"ro_product_manufacturer\": 60, \"ro_product_model\": 63, \"ro_secure\": 73, \"rom\": 112, \"root\": 43, \"rssi_list\": 108, \"sdid1\": 12, \"sdid2\": 13, \"sdid3\": 14, \"sdk__times\": 5, \"sdk__ver\": 3, \"self_id\": 80, \"serial\": 20, \"signatures\": 83, \"space\": 40, \"ssid\": 104, \"ssid_list\": 106, \"store\": 4, \"sys_boot_id\": 115, \"sys_uuid\": 116, \"system__boot__time\": 39, \"tags\": 32, \"temperature\": 117, \"time\": 82, \"times\": 1, \"trace\": 92, \"uptime\": 89, \"user\": 33, \"ver__code\": 17, \"ver__name\": 18, \"voltage\": 118, \"wifi_interface\": 49}";
   private static final JSONObject COLUMNS_INDEX_JSON = JSONObject.parseObject("{\"aiuid\": 84, \"android_id\": 123, \"apkid\": 36, \"apkpath\": 87, \"apksize\": 86, \"app__label\": 19, \"battery__ac\": 45, \"battery__level\": 47, \"battery__usb\": 46, \"bd_deviceid\": 119, \"bluetooth\": 110, \"board\": 21, \"bootloader\": 22, \"bssid\": 105, \"bssid_list\": 107, \"cell_id\": 101, \"cid\": 98, \"cpu__abi\": 23, \"cpu__abi2\": 24, \"cpuinfo\": 42, \"curtime\": 88, \"device\": 25, \"did\": 0,\"tmp_did\": 0, \"did1\": 9, \"did2\": 10, \"did3\": 11, \"display\": 44, \"existing\": 122, \"first__install__time\": 15, \"fme\": 120, \"fonts\": 121, \"gateway_mac\": 8, \"gsm_current_phone_type\": 61, \"gsm_network_type\": 62, \"gsm_operator_isroaming\": 68, \"gsm_operator_numeric\": 95, \"gsm_sim_state\": 50, \"gsm_version_baseband\": 90, \"gsm_version_ril_impl\": 91, \"hardware\": 26, \"host\": 27, \"iccid\": 37, \"id\": 28, \"imei\": 34, \"imei__native\": 35, \"imei_validation\": 124, \"imsi\": 38, \"init_svc_adbd\": 99, \"ip\": 2, \"lac_id\": 103, \"last__update__time\": 16, \"launcher\": 41, \"ldid\": 93, \"mac__addr\": 6, \"mac__framework\": 7, \"manufacturer\": 29, \"md5\": 81, \"mobilestate\": 109, \"model\": 30, \"msg\": 94, \"net_hostname\": 51, \"networkstate\": 48, \"opt_id\": 102, \"persist_radio_plmnname_2\": 79, \"persist_sys_country\": 78, \"persist_sys_timezone\": 77, \"pid\": 113, \"pkg_name\": 100, \"pkglist\": 125, \"ppid\": 114, \"product\": 31, \"ram\": 111, \"ril_subscription_types\": 96, \"ro_adb_secure\": 69, \"ro_board_platform\": 85, \"ro_boot_serialno\": 54, \"ro_build_display_id\": 97, \"ro_build_fingerprint\": 52, \"ro_build_type\": 53, \"ro_build_version_release\": 64, \"ro_chipname\": 55, \"ro_com_google_clientidbase\": 66, \"ro_csc_country_code\": 74, \"ro_csc_sales_code\": 75, \"ro_debuggable\": 76, \"ro_gps_agps_provider\": 65, \"ro_kernel_qemu\": 72, \"ro_multisim_simslotcount\": 70, \"ro_nfc_port\": 71, \"ro_opengles_version\": 56, \"ro_product_board\": 57, \"ro_product_brand\": 58, \"ro_product_cpu_abi\": 59, \"ro_product_device\": 67, \"ro_product_manufacturer\": 60, \"ro_product_model\": 63, \"ro_secure\": 73, \"rom\": 112, \"root\": 43, \"rssi_list\": 108, \"sdid1\": 12, \"sdid2\": 13, \"sdid3\": 14, \"sdk__times\": 5, \"sdk__ver\": 3, \"self_id\": 80, \"serial\": 20, \"signatures\": 83, \"space\": 40, \"ssid\": 104, \"ssid_list\": 106, \"store\": 4, \"sys_boot_id\": 115, \"sys_uuid\": 116, \"system__boot__time\": 39, \"tags\": 32, \"temperature\": 117, \"time\": 82, \"times\": 1, \"trace\": 92, \"uptime\": 89, \"user\": 33, \"ver__code\": 17, \"ver__name\": 18, \"voltage\": 118, \"wifi_interface\": 49}");


   public static String parseDate(String date, String old_format, String new_format) {
      try {
         if(StringUtils.isNotBlank(date)) {
            SimpleDateFormat e = new SimpleDateFormat(old_format);
            SimpleDateFormat newFormat = new SimpleDateFormat(new_format);
            Date d = e.parse(date);
            return newFormat.format(d);
         }
      } catch (ParseException var6) {
         var6.printStackTrace();
      }

      return "";
   }

   public static void main(String[] args) throws Exception {
      if(args.length < 16) {
         System.err.println(args.length);
         System.err.println("Usage:cn.shuzilm.odps.Ods_dna_export stg_dna_info_h dna_extract 20150101 20160101 pkg_name channels is_all_data has_update");
         System.exit(1);
      }

      String ods_dna_info_d = args[0];
      String ods_dna_info_d_illegal = "ods_ios_dna_info_h_illegal";
      String out_put_tbl = args[1];
      String start_time = args[2];
      String end_time = args[3];
      String pkg_names = args[4].toLowerCase();
      String channels = args[5];
      String ver_names = args[6];
      String columns = args[7];
      String rule_no_invalid = args[8];
      String if_show_whole = args[9];
      String show_idfa_trusted_status_list = args[10];
      String show_app_install_status_list = args[11];
      String CHANNLE_LINK_ID = args[12];
      String CDID = args[13];
      String DID = args[14];
      String IP = args[15];
      String cid_in = args[16].toLowerCase();
      String start_day = start_time.substring(0, 8);
      String end_day = end_time.substring(0, 8);
      String end_hour = end_time.substring(8, 10);
      JobConf job = new JobConf();
      job.set("start_time", start_time);
      job.set("end_time", end_time);
      job.set("pkg", pkg_names);
      job.set("filter_cid", cid_in);
      job.set("channel_list", channels);
      job.set("ver_name_list", ver_names);
      job.set("column_list", columns);
      if(!rule_no_invalid.equals("rule_no_empty")) {
         job.set("rule_no_invalid_list", rule_no_invalid);
      }

      job.set("if_show_whole", if_show_whole);
      if(!CDID.equals("cdid_empty")) {
         job.set("cdid_list", CDID);
      }

      if(!DID.equals("did_empty")) {
         job.set("did_list", DID);
      }

      if(!IP.equals("ip_empty")) {
         job.set("ip_list", IP);
      }

      if(!CHANNLE_LINK_ID.equals("chl_link_id_empty")) {
         job.set("channel_link_id_list", CHANNLE_LINK_ID);
      }

      if(!show_idfa_trusted_status_list.equals("show_idfa_trusted_status_empty")) {
         job.set("show_idfa_trusted_status_list", show_idfa_trusted_status_list);
      }

      if(!show_app_install_status_list.equals("show_app_install_status_empty")) {
         job.set("show_app_install_status_list", show_app_install_status_list);
      }

      job.setNumReduceTasks(0);
      job.setMapperClass(OdsIosDnaDetail2D.Mapper.class);
      DateTimeFormatter fmt = DateTimeFormat.forPattern("yyyyMMdd");
      DateTime dateTime = fmt.parseDateTime(start_day);
      DateTime end_dateTime = fmt.parseDateTime(end_day);
      if(end_hour.equals("00")) {
         end_dateTime.minusDays(1);
      }

      while(dateTime.compareTo(end_dateTime) <= 0) {
         InputUtils.addTable(TableInfo.builder().tableName(ods_dna_info_d).partSpec("day=" + dateTime.toString(fmt) + "/pkgname=default").build(), job);
         InputUtils.addTable(TableInfo.builder().tableName(ods_dna_info_d).partSpec("day=" + dateTime.toString(fmt) + "/pkgname=com_meelive_ingkee").build(), job);
         InputUtils.addTable(TableInfo.builder().tableName(ods_dna_info_d_illegal).partSpec("day=" + dateTime.toString(fmt) + "/pkgname=default").build(), job);
         InputUtils.addTable(TableInfo.builder().tableName(ods_dna_info_d_illegal).partSpec("day=" + dateTime.toString(fmt) + "/pkgname=com_meelive_ingkee").build(), job);
         dateTime = dateTime.plusDays(1);
      }

      OutputUtils.addTable(TableInfo.builder().tableName(out_put_tbl).build(), job);
      JobClient.runJob(job);
   }


   public static class Mapper extends MapperBase {

      private Record result;
      private String filter_cid;
      private ArrayList ver_name_list = new ArrayList();
      private ArrayList ip_list = new ArrayList();
      private ArrayList pkg_list = new ArrayList();
      private ArrayList did_list = new ArrayList();
      private ArrayList cdid_list = new ArrayList();
      private ArrayList rule_no_invalid_list = new ArrayList();
      private ArrayList show_idfa_trusted_status_list = new ArrayList();
      private ArrayList show_app_install_status_list = new ArrayList();
      private ArrayList column_list = new ArrayList();
      public static int SHOW_STATE = 0;
      public static int NOT_SHOW_STATE = 1;
      private String start_time = "";
      private int viewState;
      private String end_time;


      public Mapper() {
         this.viewState = NOT_SHOW_STATE;
         this.end_time = "";
      }

      public void setup(TaskContext context) throws IOException {
         this.result = context.createOutputRecord();
         String channels = context.getJobConf().get("channel_list");
         String if_show_whole = context.getJobConf().get("if_show_whole");
         String ver_names = context.getJobConf().get("ver_name_list");
         String ip_str;
         if(ver_names.equals("ver_names")) {
            this.ver_name_list = null;
         } else {
            String[] columns_string = ver_names.split(",");
            int show_idfa_trusted_status_str = columns_string.length;

            for(int show_app_install_status_str = 0; show_app_install_status_str < show_idfa_trusted_status_str; ++show_app_install_status_str) {
               ip_str = columns_string[show_app_install_status_str];
               if(ip_str != null && !ip_str.isEmpty() && !"null".equals(ip_str.toLowerCase())) {
                  this.ver_name_list.add(ip_str.toLowerCase());
               }
            }
         }

         String var13 = context.getJobConf().get("column_list").toLowerCase();
         this.column_list.addAll(Arrays.asList(var13.split(",")));
         String var14 = context.getJobConf().get("show_idfa_trusted_status_list");
         String var15 = context.getJobConf().get("show_app_install_status_list");
         int pkg_list_str;
         int did_str;
         String cdid_str;
         String[] var16;
         if(var14 != null) {
            var16 = var14.split(",");
            pkg_list_str = var16.length;

            for(did_str = 0; did_str < pkg_list_str; ++did_str) {
               cdid_str = var16[did_str];
               this.show_idfa_trusted_status_list.add(parseIdfaStatus(cdid_str));
            }
         }

         if(var15 != null) {
            var16 = var15.split(",");
            pkg_list_str = var16.length;

            for(did_str = 0; did_str < pkg_list_str; ++did_str) {
               cdid_str = var16[did_str];
               this.show_app_install_status_list.add(parseAppStatus(cdid_str, (String)null));
            }
         }

         if(Integer.parseInt(if_show_whole) == SHOW_STATE) {
            this.viewState = SHOW_STATE;
         }

         ip_str = context.getJobConf().get("ip_list");
         if(ip_str != null && !ip_str.equals("ip_empty")) {
            this.ip_list.addAll(Arrays.asList(ip_str.split(",")));
         }

         String var17 = context.getJobConf().get("pkg");
         if(!StringUtils.isBlank(var17) && var17.contains(".")) {
            this.pkg_list.addAll(Arrays.asList(var17.split(",")));
         }

         this.filter_cid = context.getJobConf().get("filter_cid");
         String var18 = context.getJobConf().get("did_list");
         if(var18 != null && !var18.isEmpty() && var18.toLowerCase() != "null" && !var18.equals("did_empty")) {
            this.did_list.addAll(Arrays.asList(var18.split(",")));
         }

         cdid_str = context.getJobConf().get("cdid_list");
         if(cdid_str != null && !cdid_str.isEmpty() && cdid_str.toLowerCase() != "null" && !cdid_str.equals("cdid_empty")) {
            this.cdid_list.addAll(Arrays.asList(cdid_str.split(",")));
         }

         String rule_no_invalid_str = context.getJobConf().get("rule_no_invalid_list");
         if(rule_no_invalid_str != null && !rule_no_invalid_str.equals("rule_no_empty")) {
            this.rule_no_invalid_list.addAll(Arrays.asList(rule_no_invalid_str.split(",")));
         }

         this.start_time = context.getJobConf().get("start_time");
         this.end_time = context.getJobConf().get("end_time");
         System.err.println(var17 + "\n" + channels + "\n" + ver_names + "\n");
      }

      public static boolean time_fit(String ts, String start_time, String end_time) {
         if(StringUtils.isNotBlank(start_time) && StringUtils.isNotBlank(end_time) && StringUtils.isNotBlank(ts)) {
            String databaseTs = OdsIosDnaDetail2D.parseDate(ts, "yyyy-MM-dd HH:mm:ss", "yyyyMMddHH");
            return databaseTs.compareTo(start_time) >= 0 && databaseTs.compareTo(end_time) < 0;
         } else {
            return false;
         }
      }

      public boolean if_filter_pass(Record record) {
         String pkg_name = record.getString("pkg_name");
         if(pkg_name != null && !this.pkg_list.isEmpty() && !this.pkg_list.contains(pkg_name.toLowerCase())) {
            System.out.println("1");
            return false;
         } else {
            String cid = record.getString("cid");
            if(cid != null && !this.filter_cid.isEmpty() && !this.filter_cid.equals(cid.toLowerCase())) {
               System.out.println("x");
               return false;
            } else {
               String ver_name = record.getString("appver");
               if(this.ver_name_list != null && !this.ver_name_list.isEmpty() && !this.ver_name_list.contains(ver_name)) {
                  System.out.println("3");
                  return false;
               } else {
                  String ts = record.getString("ts");
                  if(!time_fit(ts, this.start_time, this.end_time)) {
                     System.out.println("4");
                     return false;
                  } else {
                     String did = record.getString("did");
                     if(this.did_list != null && !this.did_list.isEmpty() && !this.did_list.contains(did)) {
                        System.out.println("5" + (String)this.did_list.get(0) + "---" + did + "**********" + ((String)this.did_list.get(0)).equals(did));
                        return false;
                     } else {
                        String cdid = record.getString("cdid");
                        if(this.cdid_list != null && !this.cdid_list.isEmpty() && !this.cdid_list.contains(cdid)) {
                           System.out.println("6");
                           return false;
                        } else {
                           String ip = record.getString("ip");
                           if(this.ip_list != null && !this.ip_list.isEmpty() && !this.ip_list.contains(ip)) {
                              System.out.println("7");
                              return false;
                           } else {
                              String idfa_trusted_status = record.getString("idfa_trusted_status");
                              String app_install_status = record.getString("app_install_status");
                              int viewable = parseUserViewable(app_install_status, idfa_trusted_status);
                              String rule_no_invalid;
                              if(SHOW_STATE == viewable) {
                                 rule_no_invalid = parseIdfaStatus(idfa_trusted_status);
                                 if(!"INVALID".equals(rule_no_invalid)) {
                                    String if_contain_rule_no_invalid = parseAppStatus(app_install_status, idfa_trusted_status);
                                    if(this.show_app_install_status_list != null && !this.show_app_install_status_list.isEmpty() && !this.show_app_install_status_list.contains(if_contain_rule_no_invalid)) {
                                       System.out.println("8");
                                       return false;
                                    }
                                 }

                                 if(this.show_idfa_trusted_status_list != null && !this.show_idfa_trusted_status_list.isEmpty() && !this.show_idfa_trusted_status_list.contains(rule_no_invalid)) {
                                    System.out.println("9");
                                    return false;
                                 }
                              } else if(this.viewState == NOT_SHOW_STATE) {
                                 System.out.println("10");
                                 return false;
                              }

                              rule_no_invalid = record.getString("rule_no_invalid");
                              if(this.rule_no_invalid_list != null && !this.rule_no_invalid_list.isEmpty()) {
                                 boolean if_contain_rule_no_invalid1 = false;
                                 Iterator var14 = this.rule_no_invalid_list.iterator();

                                 while(var14.hasNext()) {
                                    String flow_rule_no_invalid = (String)var14.next();
                                    if(rule_no_invalid.contains(flow_rule_no_invalid)) {
                                       if_contain_rule_no_invalid1 = true;
                                       break;
                                    }
                                 }

                                 return if_contain_rule_no_invalid1;
                              } else {
                                 return true;
                              }
                           }
                        }
                     }
                  }
               }
            }
         }
      }

      public void fillData(Record record, ArrayList columnList) {
         int j = 0;
         Iterator var4 = columnList.iterator();

         while(var4.hasNext()) {
            String column = (String)var4.next();

            try {
               byte var13 = -1;
               switch(column.hashCode()) {
               case -1196813993:
                  if(column.equals("tmp_did")) {
                     var13 = 5;
                  }
                  break;
               case -192833752:
                  if(column.equals("firstruntime")) {
                     var13 = 3;
                  }
                  break;
               case 913801460:
                  if(column.equals("app_install_status")) {
                     var13 = 0;
                  }
                  break;
               case 1048437891:
                  if(column.equals("idfa_trusted_status")) {
                     var13 = 1;
                  }
                  break;
               case 1127003405:
                  if(column.equals("curtime")) {
                     var13 = 2;
                  }
                  break;
               case 2013906111:
                  if(column.equals("boottime")) {
                     var13 = 4;
                  }
               }

               String val;
               switch(var13) {
               case 0:
                  String e = record.getString("app_install_status");
                  String str1 = record.getString("idfa_trusted_status");
                  String app_result = parseAppStatus(e, str1);
                  System.out.println("times_result" + app_result);
                  this.result.set(j++, app_result);
                  break;
               case 1:
                  String idfa_trusted_status = record.getString("idfa_trusted_status");
                  String idfa_result = parseIdfaStatus(idfa_trusted_status);
                  System.out.println("times_result" + idfa_result);
                  this.result.set(j++, idfa_result);
                  break;
               case 2:
               case 3:
               case 4:
                  val = record.getString(column);
                  this.result.set(j++, Utils.timestamp_2_date(val));
                  break;
               case 5:
                  val = record.getString("cdid");
                  System.out.println("tmp_did:" + val);
                  this.result.set(j++, val);
                  break;
               default:
                  this.result.set(j++, record.getString(column));
               }
            } catch (NullPointerException var14) {
               ++j;
               System.out.println("null , " + j + " , " + column);
            } catch (Exception var15) {
               var15.printStackTrace();
               System.out.println("null , " + j + " , " + column);
            }
         }

      }

      public void map(long recordNum, Record record, TaskContext context) throws IOException {
         try {
            if(this.if_filter_pass(record)) {
               this.fillData(record, this.column_list);
               context.write(this.result);
            }
         } catch (Exception var6) {
            var6.printStackTrace();
         }

      }

      private static String parseIdfaStatus(String idfa_trusted_status) {
         if(null == idfa_trusted_status) {
            return null;
         } else {
            byte var2 = -1;
            switch(idfa_trusted_status.hashCode()) {
            case 48:
               if(idfa_trusted_status.equals("0")) {
                  var2 = 0;
               }
               break;
            case 49:
               if(idfa_trusted_status.equals("1")) {
                  var2 = 1;
               }
               break;
            case 50:
               if(idfa_trusted_status.equals("2")) {
                  var2 = 2;
               }
               break;
            case 51:
               if(idfa_trusted_status.equals("3")) {
                  var2 = 3;
               }
               break;
            case 52:
               if(idfa_trusted_status.equals("4")) {
                  var2 = 4;
               }
            }

            switch(var2) {
            case 0:
               return "NU";
            case 1:
               return "Y";
            case 2:
               return "N";
            case 3:
            case 4:
               return "INVALID";
            default:
               return idfa_trusted_status;
            }
         }
      }

      private static String parseAppStatus(String app_install_status, String idfa_trusted_status) {
         if(null == app_install_status) {
            return null;
         } else {
            byte var3 = -1;
            switch(app_install_status.hashCode()) {
            case 48:
               if(app_install_status.equals("0")) {
                  var3 = 0;
               }
               break;
            case 49:
               if(app_install_status.equals("1")) {
                  var3 = 1;
               }
               break;
            case 50:
               if(app_install_status.equals("2")) {
                  var3 = 2;
               }
               break;
            case 51:
               if(app_install_status.equals("3")) {
                  var3 = 3;
               }
            }

            switch(var3) {
            case 0:
               return "新增";
            case 1:
               return "重复";
            case 2:
               return "召回";
            case 3:
               return "更新";
            default:
               return !"3".equals(idfa_trusted_status) && !"4".equals(idfa_trusted_status)?app_install_status:"INVALID";
            }
         }
      }

      private static int parseUserViewable(String app_install_status, String idfa_trusted_status) {
         if(null == app_install_status) {
            return NOT_SHOW_STATE;
         } else {
            byte var3 = -1;
            switch(app_install_status.hashCode()) {
            case 48:
               if(app_install_status.equals("0")) {
                  var3 = 0;
               }
               break;
            case 49:
               if(app_install_status.equals("1")) {
                  var3 = 1;
               }
               break;
            case 50:
               if(app_install_status.equals("2")) {
                  var3 = 2;
               }
               break;
            case 51:
               if(app_install_status.equals("3")) {
                  var3 = 3;
               }
               break;
            case 1389220:
               if(app_install_status.equals("-100")) {
                  var3 = 4;
               }
            }

            switch(var3) {
            case 0:
            case 1:
            case 2:
            case 3:
               return SHOW_STATE;
            case 4:
               if(!"3".equals(idfa_trusted_status) && !"4".equals(idfa_trusted_status)) {
                  return NOT_SHOW_STATE;
               }

               return SHOW_STATE;
            default:
               return NOT_SHOW_STATE;
            }
         }
      }

   }
}
